==> aidlab_sdk-0.0.21.tar.gz: lib/src/wrappers/aidlab_synchronization_wrapper.dart <==
import 'dart:developer';

import 'package:aidlab_sdk/aidlab_sdk.dart';
import 'package:aidlab_sdk/src/wrappers/platform_aidlab_sdk.dart';

class AidlabSynchronizationWrapper
    implements PlatformAidlabSynchronizationDelegate {
  final Aidlab aidlab;
  AidlabSynchronizationDelegate? delegate;

  AidlabSynchronizationWrapper(this.aidlab) {
    PlatformAidlabSynchronizationDelegate.setup(this);
  }

  static void release() {
    PlatformAidlabSynchronizationDelegate.setup(null);
  }

  @override
  void didReceivePastActivity(ActivityEvent arg) {
    delegate?.didReceivePastActivity(aidlab, arg.timestamp!,
        ActivityTypeExtension.fromValue(arg.activityType!));
  }

  @override
  void didReceivePastECG(EcgEvent arg) {
    delegate?.didReceivePastECG(aidlab, arg.timestamp!, arg.values!.toList());
  }

  @override
  void didReceivePastHeartRate(HeartRateEvent arg) {
    delegate?.didReceivePastHeartRate(aidlab, arg.timestamp!, arg.heartRate!);
  }

  @override
  void didReceivePastRr(RrEvent arg) {
    delegate?.didReceivePastRr(aidlab, arg.timestamp!, arg.rr!);
  }

  @override
  void didReceivePastRespiration(RespirationEvent arg) {
    delegate?.didReceivePastRespiration(
        aidlab, arg.timestamp!, arg.values!.toList());
  }

  @override
  void didReceivePastRespirationRate(RespirationRateEvent arg) {
    delegate?.didReceivePastRespirationRate(aidlab, arg.timestamp!, arg.value!);
  }

  @override
  void didReceivePastSkinTemperature(SkinTemperatureEvent arg) {
    delegate?.didReceivePastSkinTemperature(aidlab, arg.timestamp!, arg.value!);
  }

  @override
  void didReceivePastSteps(StepsEvent arg) {
    delegate?.didReceivePastSteps(aidlab, arg.timestamp!, arg.value!);
  }

  @override
  void didReceiveUnsynchronizedSize(UnsynchronizedSizeEvent arg) {
    delegate?.didReceiveUnsynchronizedSize(aidlab, arg.unsynchronizedSize!, arg.syncBytesPerSecond!);
  }

  @override
  void syncStateDidChange(SyncStateEvent arg) {
    log("syncStateDidChange - ${arg.state}");
    delegate?.syncStateDidChange(
        aidlab, SyncStateExtension.fromValue(arg.state!));
  }

  @override
  void didReceivePastAccelerometer(VectorEvent arg) {
    delegate?.didReceivePastAccelerometer(
        aidlab, arg.timestamp!, arg.x!, arg.y!, arg.z!);
  }

  @override
  void didReceivePastBodyPosition(BodyPositionEvent arg) {
    delegate?.didReceivePastBodyPosition(aidlab, arg.timestamp!,
        BodyPositionExtension.fromValue(arg.bodyPosition!));
  }

  @override
  void didReceivePastGyroscope(VectorEvent arg) {
    delegate?.didReceivePastGyroscope(
        aidlab, arg.timestamp!, arg.x!, arg.y!, arg.z!);
  }

  @override
  void didReceivePastMagnetometer(VectorEvent arg) {
    delegate?.didReceivePastMagnetometer(
        aidlab, arg.timestamp!, arg.x!, arg.y!, arg.z!);
  }

  @override
  void didReceivePastOrientation(OrientationEvent arg) {
    delegate?.didReceivePastOrientation(
        aidlab, arg.timestamp!, arg.roll!, arg.pitch!, arg.yaw!);
  }

  @override
  void didReceivePastPressure(PressureEvent arg) {
    delegate?.didReceivePastPressure(aidlab, arg.timestamp!, arg.values!);
  }

  @override
  void didReceivePastQuaternion(QuaternionEvent arg) {
    delegate?.didReceivePastQuaternion(
        aidlab, arg.timestamp!, arg.qw!, arg.qx!, arg.qy!, arg.qz!);
  }

  @override
  void didReceivePastSoundVolume(SoundVolumeEvent arg) {
    delegate?.didReceivePastSoundVolume(
        aidlab, arg.timestamp!, arg.soundVolume!);
  }

  @override
  void didDetectPastUserEvent(UserEvent arg) {
    delegate?.didDetectPastUserEvent(aidlab, arg.timestamp!);
  }

  @override
  void didReceivePastSoundFeatures(SoundFeaturesEvent arg) {
    delegate?.didReceivePastSoundFeatures(aidlab, arg.values!);
  }

  @override
  void didReceivePastSignalQuality(SignalQualityEvent arg) {
    delegate?.didReceivePastSignalQuality(aidlab, arg.timestamp!, arg.value!);
  }
}

==> aidlab_sdk-0.2.0.tar.gz: lib/src/wrappers/aidlab_synchronization_wrapper.dart <==
import 'dart:developer';

import 'package:aidlab_sdk/aidlab_sdk.dart';
import 'package:aidlab_sdk/src/wrappers/platform_aidlab_sdk.dart';

class AidlabSynchronizationWrapper
    implements PlatformAidlabSynchronizationDelegate {
  final Aidlab aidlab;
  AidlabSynchronizationDelegate? delegate;

  AidlabSynchronizationWrapper(this.aidlab) {
    PlatformAidlabSynchronizationDelegate.setup(this);
  }

  static void release() {
    PlatformAidlabSynchronizationDelegate.setup(null);
  }

  @override
  void didReceivePastActivity(ActivityEvent arg) {
    delegate?.didReceivePastActivity(aidlab, arg.timestamp,
        ActivityTypeExtension.fromValue(arg.activityType));
  }

  @override
  void didReceivePastECG(EcgEvent arg) {
    delegate?.didReceivePastECG(aidlab, arg.timestamp, arg.values.toList());
  }

  @override
  void didReceivePastHeartRate(HeartRateEvent arg) {
    delegate?.didReceivePastHeartRate(aidlab, arg.timestamp, arg.heartRate);
  }

  @override
  void didReceivePastRr(RrEvent arg) {
    delegate?.didReceivePastRr(aidlab, arg.timestamp, arg.rr);
  }

  @override
  void didReceivePastRespiration(RespirationEvent arg) {
    delegate?.didReceivePastRespiration(
        aidlab, arg.timestamp, arg.values.toList());
  }

  @override
  void didReceivePastRespirationRate(RespirationRateEvent arg) {
    delegate?.didReceivePastRespirationRate(aidlab, arg.timestamp, arg.value);
  }

  @override
  void didReceivePastSkinTemperature(SkinTemperatureEvent arg) {
    delegate?.didReceivePastSkinTemperature(aidlab, arg.timestamp, arg.value);
  }

  @override
  void didReceivePastSteps(StepsEvent arg) {
    delegate?.didReceivePastSteps(aidlab, arg.timestamp, arg.value);
  }

  @override
  void didReceiveUnsynchronizedSize(UnsynchronizedSizeEvent arg) {
    delegate?.didReceiveUnsynchronizedSize(
        aidlab, arg.unsynchronizedSize, arg.syncBytesPerSecond);
  }

  @override
  void syncStateDidChange(SyncStateEvent arg) {
    log("syncStateDidChange - ${arg.state}");
    delegate?.syncStateDidChange(
        aidlab, SyncStateExtension.fromValue(arg.state));
  }

  @override
  void didReceivePastAccelerometer(VectorEvent arg) {
    delegate?.didReceivePastAccelerometer(
        aidlab, arg.timestamp, arg.x, arg.y, arg.z);
  }

  @override
  void didReceivePastBodyPosition(BodyPositionEvent arg) {
    delegate?.didReceivePastBodyPosition(aidlab, arg.timestamp,
        BodyPositionExtension.fromValue(arg.bodyPosition));
  }

  @override
  void didReceivePastGyroscope(VectorEvent arg) {
    delegate?.didReceivePastGyroscope(
        aidlab, arg.timestamp, arg.x, arg.y, arg.z);
  }

  @override
  void didReceivePastMagnetometer(VectorEvent arg) {
    delegate?.didReceivePastMagnetometer(
        aidlab, arg.timestamp, arg.x, arg.y, arg.z);
  }

  @override
  void didReceivePastOrientation(OrientationEvent arg) {
    delegate?.didReceivePastOrientation(
        aidlab, arg.timestamp, arg.roll, arg.pitch, arg.yaw);
  }

  @override
  void didReceivePastPressure(PressureEvent arg) {
    delegate?.didReceivePastPressure(aidlab, arg.timestamp!, arg.values!);
  }

  @override
  void didReceivePastQuaternion(QuaternionEvent arg) {
    delegate?.didReceivePastQuaternion(
        aidlab, arg.timestamp, arg.qw, arg.qx, arg.qy, arg.qz);
  }

  @override
  void didReceivePastSoundVolume(SoundVolumeEvent arg) {
    delegate?.didReceivePastSoundVolume(aidlab, arg.timestamp, arg.soundVolume);
  }

  @override
  void didDetectPastUserEvent(UserEvent arg) {
    delegate?.didDetectPastUserEvent(aidlab, arg.timestamp);
  }

  @override
  void didReceivePastSoundFeatures(SoundFeaturesEvent arg) {
    delegate?.didReceivePastSoundFeatures(aidlab, arg.values);
  }

  @override
  void didReceivePastSignalQuality(SignalQualityEvent arg) {
    delegate?.didReceivePastSignalQuality(aidlab, arg.timestamp, arg.value);
  }
}
